@@ -21,7 +21,7 @@
 // include
 #include "internal/iutest_result_reporter.hpp"
 #include "internal/iutest_params_util.hpp"
-#include "internal/iutest_file.h"
+#include "internal/iutest_file.hpp"
 
 namespace iutest
 {
@@ -71,17 +71,17 @@ public:
 	/** eXg */
 	int				successful_test_count(void)	const	{ return test_to_run_count() - failed_test_count(); }
 	/** XLbveXg */
-	int				skip_test_count(void)		const	{ return total_test_count() - test_to_run_count(); }
+	int				skip_test_count(void)		const	{ return get_skipped_test_count(); }
 
 	/** eXgP[X̑ */
-	int				total_test_case_count(void)	const	{ return m_testcases.count(); }
+	int				total_test_case_count(void)	const	{ return m_testcases.size(); }
 	/** seXgP[X */
 	int				test_case_to_run_count(void)	const
 	{
 		int count=0;
-		for( iuTestCases::iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
 		{
-			if( !it->should_run() ) continue;
+			if( !(*it)->should_run() ) continue;
 			++count;
 		}
 		return count;
@@ -90,10 +90,10 @@ public:
 	int				successful_test_case_count(void)	const
 	{
 		int count=0;
-		for( iuTestCases::iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
 		{
-			if( !it->should_run() ) continue;
-			if( it->failed_test_count() == 0 ) ++count;
+			if( !(*it)->should_run() ) continue;
+			if( (*it)->failed_test_count() == 0 ) ++count;
 		}
 		return count;
 	}
@@ -101,10 +101,10 @@ public:
 	int				failed_test_case_count(void)	const
 	{
 		int count=0;
-		for( iuTestCases::iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		for( iuTestCases::const_iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
 		{
-			if( !it->should_run() ) continue;
-			if( it->failed_test_count() > 0 ) ++count;
+			if( !(*it)->should_run() ) continue;
+			if( (*it)->failed_test_count() > 0 ) ++count;
 		}
 		return count;
 	}
@@ -127,207 +127,44 @@ protected:
 	/**
 	 * @brief	eXg̎s
 	*/
-	int Run(void)
-	{
-		if( !PreRunner() ) return 0;
-
-		int ret = 1;
-#if IUTEST_HAS_EXCEPTIONS
-		if( TestFlag::IsEnableFlag(TestFlag::CATCH_EXCEPTION_GLOBAL) )
-		{
-			try
-			{
-#if IUTEST_HAS_SEH
-				ret = RunOnMSC();
-#else
-				ret = RunImpl();
-#endif
-			}
-			catch( ... )
-			{
-			}
-		}
-		else
-#endif
-		{
-			ret = RunImpl();
-		}
-		return ret;
-	}
-protected:
-#if IUTEST_HAS_EXCEPTIONS && IUTEST_HAS_SEH
-	int	RunOnMSC(void)
-	{
-		_EXCEPTION_POINTERS* info = NULL;
-		int ret = 1;
-		__try
-		{
-			ret = RunImpl();
-		}
-		__except (info = GetExceptionInformation()
-			, detail::seh_exception::should_process_through_break_and_cppexceptions(GetExceptionCode()))
-		{
-			detail::seh_exception::translator(GetExceptionCode(), info);
-		}
-		return ret;
-	}
-#endif
+	int Run(void);
 
 private:
-	int RunImpl(void)
-	{
-		m_repeat_counter = 0;
-		int repeat = TestEnv::get_repeat_count();
-		if( repeat == 0 ) return 0;
-
-		TestProgramStart();
-
-		bool result = true;
-		while(repeat)
-		{
-			SetUpTestIteration();
-
-			listeners().OnTestIterationStart(*this, m_repeat_counter);
-			if( !RunOnce() )
-			{
-				result = false;
-			}
-			listeners().OnTestIterationEnd(*this, m_repeat_counter);
-
-			++m_repeat_counter;
-			if( repeat > 0 ) --repeat;
-		}
-
-		TestProgramEnd();
-
-		return result ? 0 : 1;
-	}
-
-	/**
-	 * @brief	vO̊Jn
-	*/
-	void	TestProgramStart(void)
-	{
-#if 0
-#if IUTEST_HAS_EXCEPTIONS && defined(_MSC_VER) && IUTEST_HAS_SEH
-		// /EHa IvVKv
-		if( TestFlag::IsEnableFlag(TestFlag::CATCH_EXCEPTION) )
-		{
-			// SEH OɑΉ
-			_set_se_translator(detail::seh_exception::translator);
-		}
+#if IUTEST_HAS_EXCEPTIONS && IUTEST_HAS_SEH
+	int	RunOnMSC(void);
 #endif
-#endif
-
-		// tB^O
-		m_should_run_num = 0;
-		m_disable_num = 0;
-		for( iuTestCases::iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
-		{
-			it->filter();
-			m_should_run_num += it->test_to_run_count();
-			m_disable_num += it->disabled_test_count();
-		}
-
-		atexit(OnExit);
-
-		listeners().OnTestProgramStart(*this);
-	}
-
-	/**
-	 * @brief	Ce[ṼZbgAbv
-	*/
-	void	SetUpTestIteration(void)
-	{
-		TestEnv::SetUp();
-	}
-
-	/**
-	 * @brief	ZbgAbv
-	*/
-	void	EnvironmentSetUp(void)
-	{
-		listeners().OnEnvironmentsSetUpStart(*this);
-		for( iuEnvironmentList::iterator it = TestEnv::environments().begin(), end=TestEnv::environments().end(); it != end; ++it )
-		{
-			(*it)->SetUp();
-		}
-		listeners().OnEnvironmentsSetUpEnd(*this);
-	}
+	int RunImpl(void);
 
 	/**
 	 * @brief	eXg̎siP[vj
 	*/
-	bool	RunOnce(void)
-	{
-		m_elapsedmsec = 0;
+	bool	RunOnce(void);
 
-		// sΏۂ̃eXgȂꍇ͉Ȃ
-		if( test_to_run_count() == 0 ) return Passed();
+private:
+	/**
+	 * @brief	vO̊Jn
+	*/
+	void	TestProgramStart(void);
 
-		// eXgʂ̃NA
-		for( iuTestCases::iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
-		{
-			it->clear();
-		}
+	/**
+	 * @brief	Ce[ṼZbgAbv
+	*/
+	void	SetUpTestIteration(void);
 
-		// Vbt
-		if( TestFlag::IsEnableFlag(TestFlag::SHUFFLE_TESTS) )
-		{
-			m_testcases.shuffle(TestEnv::genrand());
-		}
-
-		// O[oZbg
-		EnvironmentSetUp();
-
-		if( m_ad_hoc_testresult.HasFatalFailure() )
-		{
-			return false;
-		}
-
-		{
-			detail::iuStopWatch sw;
-			sw.start();
-			for( iuTestCases::iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
-			{
-				if( !it->should_run() ) continue;
-
-				m_current_testcase = *it;
-				it->Run();
-				m_current_testcase = NULL;
-			}
-			m_elapsedmsec = sw.stop();
-		}
-
-		// O[oZbg
-		EnvironmentTearDown();
-
-		return Passed();
-	}
+	/**
+	 * @brief	ZbgAbv
+	*/
+	void	EnvironmentSetUp(void);
 
 	/**
 	 * @brief	
 	*/
-	void	EnvironmentTearDown(void)
-	{
-		listeners().OnEnvironmentsTearDownStart(*this);
-		for( iuEnvironmentList::reverse_iterator it = TestEnv::environments().rbegin(), end=TestEnv::environments().rend(); it != end; ++it )
-		{
-			(*it)->TearDown();
-		}
-		listeners().OnEnvironmentsTearDownEnd(*this);
-	}
+	void	EnvironmentTearDown(void);
 
 	/**
 	 * @brief	vȌI
 	*/
-	void	TestProgramEnd(void)
-	{
-		static bool pass = false;
-		if( pass ) return;
-		listeners().OnTestProgramEnd(*this);
-		pass = true;
-	}
+	void	TestProgramEnd(void);
 
 private:
 	// C̏IR[obN֐
@@ -339,6 +176,7 @@ private:
 private:
 	UnitTest(void)
 		: m_repeat_counter(0)
+		, m_init_iutest_count(0)
 		, m_current_testcase(NULL)
 	{
 		// ftHg|[^[Zbg
@@ -354,32 +192,25 @@ private:
 
 private:
 	// 
-	void	Initialize(void)
-	{
-#if IUTEST_HAS_PARAM_TEST
-		m_param_testcase_holder.RegisterTests();
-#endif
-
-		// t@CVXȅ
-		if( detail::IFileSystem::GetInstance() == NULL )
-		{
-#if defined(IUTEST_FILE)
-			static FileSystem<IUTEST_FILE> filesystem;
-			filesystem.Initialize();
-#elif IUTEST_HAS_FOPEN
-			static FileSystem<StdioFile> filesystem;
-			filesystem.Initialize();
-#endif
-		}
-	}
+	void	Initialize(void);
 
 	int get_failed_test_count(void) const
 	{
 		int count = 0;
-		for( iuTestCases::iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		for( iuTestCases::const_iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
 		{
-			if( !it->should_run() ) continue;
-			count += it->failed_test_count();
+			if( !(*it)->should_run() ) continue;
+			count += (*it)->failed_test_count();
+		}
+		return count;
+	}
+
+	int get_skipped_test_count(void) const
+	{
+		int count = 0;
+		for( iuTestCases::const_iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		{
+			count += (*it)->skip_test_count();
 		}
 		return count;
 	}
@@ -396,6 +227,7 @@ private:
 	friend class UnitTestSource;
 
 	int m_repeat_counter;
+	int m_init_iutest_count;
 	const TestCase*	m_current_testcase;
 	detail::DefaultGlobalTestPartResultReporter	m_default_test_part_result_reporter;
 
@@ -438,6 +270,225 @@ private:
 
 }	// end of namespace detail
 
+inline int UnitTest::Run(void)
+{
+	if( m_init_iutest_count == 0 )
+	{
+		//#if IUTEST_HAS_PARAM_TEST
+		//			if( m_param_testcase_holder.count() )
+		//#endif
+		{
+			detail::iuConsole::output("This test program did NOT call ::iutest::InitIrisUnitTest before calling IUTEST_RUN_ALL_TESTS().  Please fix it.\n");
+			return 1;
+		}
+	}
+
+	if( !PreRunner() ) return 0;
+
+	int ret = 1;
+#if IUTEST_HAS_EXCEPTIONS
+	if( TestFlag::IsEnableFlag(TestFlag::CATCH_EXCEPTION_GLOBAL) )
+	{
+		try
+		{
+#if IUTEST_HAS_SEH
+			ret = RunOnMSC();
+#else
+			ret = RunImpl();
+#endif
+		}
+		catch( ... )
+		{
+		}
+	}
+	else
+#endif
+	{
+		ret = RunImpl();
+	}
+	return ret;
+}
+
+#if IUTEST_HAS_EXCEPTIONS && IUTEST_HAS_SEH
+inline int	UnitTest::RunOnMSC(void)
+{
+	_EXCEPTION_POINTERS* info = NULL;
+	int ret = 1;
+	__try
+	{
+		ret = RunImpl();
+	}
+	__except (info = GetExceptionInformation()
+		, detail::seh_exception::should_process_through_break_and_cppexceptions(GetExceptionCode()))
+	{
+		detail::seh_exception::translator(GetExceptionCode(), info);
+	}
+	return ret;
+}
+#endif
+
+inline int UnitTest::RunImpl(void)
+{
+	m_repeat_counter = 0;
+	int repeat = TestEnv::get_repeat_count();
+	if( repeat == 0 ) return 0;
+
+	TestProgramStart();
+
+	bool result = true;
+	while(repeat)
+	{
+		SetUpTestIteration();
+
+		listeners().OnTestIterationStart(*this, m_repeat_counter);
+		if( !RunOnce() )
+		{
+			result = false;
+		}
+		listeners().OnTestIterationEnd(*this, m_repeat_counter);
+
+		++m_repeat_counter;
+		if( repeat > 0 ) --repeat;
+	}
+
+	TestProgramEnd();
+
+	return result ? 0 : 1;
+}
+
+inline bool	UnitTest::RunOnce(void)
+{
+	m_elapsedmsec = 0;
+
+	// sΏۂ̃eXgȂꍇ͉Ȃ
+	if( test_to_run_count() == 0 ) return Passed();
+
+	// eXgʂ̃NA
+	for( iuTestCases::iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+	{
+		(*it)->clear();
+	}
+
+	// Vbt
+	if( TestFlag::IsEnableFlag(TestFlag::SHUFFLE_TESTS) )
+	{
+		detail::RandomShuffle(m_testcases, TestEnv::genrand());
+	}
+
+	// O[oZbg
+	EnvironmentSetUp();
+
+	if( m_ad_hoc_testresult.HasFatalFailure() )
+	{
+		return false;
+	}
+
+	{
+		detail::iuStopWatch sw;
+		sw.start();
+		for( iuTestCases::iterator it=m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+		{
+			if( !(*it)->should_run() ) continue;
+
+			m_current_testcase = *it;
+			(*it)->Run();
+			m_current_testcase = NULL;
+		}
+		m_elapsedmsec = sw.stop();
+	}
+
+	// O[oZbg
+	EnvironmentTearDown();
+
+	return Passed();
+}
+
+inline void	UnitTest::TestProgramStart(void)
+{
+#if 0
+#if IUTEST_HAS_EXCEPTIONS && defined(_MSC_VER) && IUTEST_HAS_SEH
+	// /EHa IvVKv
+	if( TestFlag::IsEnableFlag(TestFlag::CATCH_EXCEPTION) )
+	{
+		// SEH OɑΉ
+		_set_se_translator(detail::seh_exception::translator);
+	}
+#endif
+#endif
+
+	// tB^O
+	m_should_run_num = 0;
+	m_disable_num = 0;
+	for( iuTestCases::iterator it = m_testcases.begin(), end=m_testcases.end(); it != end; ++it )
+	{
+		(*it)->filter();
+		m_should_run_num += (*it)->test_to_run_count();
+		m_disable_num += (*it)->disabled_test_count();
+	}
+
+	atexit(OnExit);
+
+	listeners().OnTestProgramStart(*this);
+}
+
+inline void	UnitTest::SetUpTestIteration(void)
+{
+	TestEnv::SetUp();
+}
+
+inline void	UnitTest::EnvironmentSetUp(void)
+{
+	listeners().OnEnvironmentsSetUpStart(*this);
+	for( iuEnvironmentList::iterator it = TestEnv::environments().begin(), end=TestEnv::environments().end(); it != end; ++it )
+	{
+		(*it)->SetUp();
+	}
+	listeners().OnEnvironmentsSetUpEnd(*this);
+}
+
+inline void	UnitTest::EnvironmentTearDown(void)
+{
+	listeners().OnEnvironmentsTearDownStart(*this);
+	for( iuEnvironmentList::reverse_iterator it = TestEnv::environments().rbegin(), end=TestEnv::environments().rend(); it != end; ++it )
+	{
+		(*it)->TearDown();
+	}
+	listeners().OnEnvironmentsTearDownEnd(*this);
+}
+
+inline void	UnitTest::TestProgramEnd(void)
+{
+	static bool pass = false;
+	if( pass ) return;
+	listeners().OnTestProgramEnd(*this);
+	pass = true;
+}
+
+inline void	UnitTest::Initialize(void)
+{
+	m_init_iutest_count++;
+
+	// t@CVXȅ
+	if( detail::IFileSystem::GetInstance() == NULL )
+	{
+#if defined(IUTEST_FILE)
+		static FileSystem<IUTEST_FILE> filesystem;
+		filesystem.Initialize();
+#elif IUTEST_HAS_FOPEN
+		static FileSystem<StdioFile> filesystem;
+		filesystem.Initialize();
+#endif
+	}
+
+	// ȍ~̂
+	if( m_init_iutest_count != 1 ) return;
+
+#if IUTEST_HAS_PARAM_TEST
+	m_param_testcase_holder.RegisterTests();
+#endif
+}
+
+
 }	// end of namespace iutest
 
 #endif
