@@ -22,7 +22,7 @@
 #include "iutest_core.hpp"
 
 #if IUTEST_HAS_PARAM_TEST
-#include "internal/iutest_pool.h"
+#include "internal/iutest_pool.hpp"
 
 //======================================================================
 // define
@@ -115,7 +115,6 @@ class ParamTestInstance : public IParamTestCaseInfo::ITestInfoData<typename T::P
 	};
 public:
 	ParamTestInstance(const char* testcase_name) : _Mybase(testcase_name) {}
-	virtual ~ParamTestInstance(void) {}
 
 private:
 	// eXgP[X̍쐬
@@ -125,30 +124,12 @@ private:
 	}
 
 	// eXg̍쐬o^
-	virtual	void	RegisterTest(TestCase* testcase, ParamType param, int index)
+	virtual	void	RegisterTest(TestCase* testcase, ParamType param, int index) const
 	{
-		EachTest* test = new EachTest(testcase, MakeTestName(index).c_str(), param);
+		EachTest* test = new EachTest(testcase, detail::MakeIndexTestName(this->m_name.c_str(), index).c_str(), param);
 		// new IuWFNgǗĂ炤
 		detail::iuPool<EachTest>::GetInstance().push(test);
 	}
-private:
-	// eXg̍쐬
-	::std::string MakeTestName(int index)
-	{
-		::std::string pname = this->m_name;
-		pname += "/";
-		detail::iuStringStream::type strm;
-		strm << index;
-		pname += strm.str().c_str();
-		return pname;
-	}
-	::std::string MakeTestNameByParam(ParamType param)
-	{
-		::std::string pname = this->m_name;
-		pname += "/";
-		pname += PrintToString(param);
-		return pname;
-	}
 };
 
 }	// end of namespace
@@ -192,7 +173,7 @@ inline detail::iuIParamGenerator< typename detail::IteratorTraits<Ite>::type >*
 	return new detail::iuValueInParamsGenerator< typename detail::IteratorTraits<Ite>::type >(begin, end);
 }
 
-#if IUTEST_HAS_VARIADIC_TEMPLATES && IUTEST_HAS_STD_TUPLE
+#if IUTEST_HAS_VARIADIC_VALUES
 /**
  * @brief	lzp[^
 */
@@ -1163,6 +1144,9 @@ static detail::iuValueArray50<T1, T2, T3, T4, T5, T6, T7, T8, T9
 #if IUTEST_HAS_COMBINE
 
 #if IUTEST_HAS_VARIADIC_COMBINE
+/**
+ * @brief	p[^
+*/
 template<typename ...Generator>
 detail::iuCartesianProductHolder<Generator...> Combine(const Generator&... generators)
 {
@@ -1238,6 +1222,84 @@ detail::iuCartesianProductHolder9<G1, G2, G3, G4, G5, G6, G7, G8, G9> Combine(co
 
 #endif
 
+#if IUTEST_HAS_PAIRWISE
+
+#if IUTEST_HAS_VARIADIC_PAIRWISE
+
+/**
+ * @brief	p[^(I[yA@)
+*/
+template<typename ...Generator>
+detail::iuPairwiseHolder<Generator...> Pairwise(const Generator&... generators)
+{
+	return detail::iuPairwiseHolder<Generator...>(generators...);
+}
+
+#else
+
+/**
+ * @brief	p[^(I[yA@)
+ * @note	9܂Ŏgp\
+*/
+template<typename G1, typename G2>
+detail::iuPairwiseHolder2<G1, G2> Pairwise(const G1& g1, const G2& g2)
+{
+	return detail::iuPairwiseHolder2<G1, G2>(g1, g2);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3>
+detail::iuPairwiseHolder3<G1, G2, G3> Pairwise(const G1& g1, const G2& g2, const G3& g3)
+{
+	return detail::iuPairwiseHolder3<G1, G2, G3>(g1, g2, g3);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4>
+detail::iuPairwiseHolder4<G1, G2, G3, G4> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4)
+{
+	return detail::iuPairwiseHolder4<G1, G2, G3, G4>(g1, g2, g3, g4);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4, typename G5>
+detail::iuPairwiseHolder5<G1, G2, G3, G4, G5> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4, const G5& g5)
+{
+	return detail::iuPairwiseHolder5<G1, G2, G3, G4, G5>(g1, g2, g3, g4, g5);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4, typename G5, typename G6>
+detail::iuPairwiseHolder6<G1, G2, G3, G4, G5, G6> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4, const G5& g5, const G6& g6)
+{
+	return detail::iuPairwiseHolder6<G1, G2, G3, G4, G5, G6>(g1, g2, g3, g4, g5, g6);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4, typename G5, typename G6, typename G7>
+detail::iuPairwiseHolder7<G1, G2, G3, G4, G5, G6, G7> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4, const G5& g5, const G6& g6, const G7& g7)
+{
+	return detail::iuPairwiseHolder7<G1, G2, G3, G4, G5, G6, G7>(g1, g2, g3, g4, g5, g6, g7);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4, typename G5, typename G6, typename G7, typename G8>
+detail::iuPairwiseHolder8<G1, G2, G3, G4, G5, G6, G7, G8> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4, const G5& g5, const G6& g6, const G7& g7, const G8& g8)
+{
+	return detail::iuPairwiseHolder8<G1, G2, G3, G4, G5, G6, G7, G8>(g1, g2, g3, g4, g5, g6, g7, g8);
+}
+
+/** @overload */
+template<typename G1, typename G2, typename G3, typename G4, typename G5, typename G6, typename G7, typename G8, typename G9>
+detail::iuPairwiseHolder9<G1, G2, G3, G4, G5, G6, G7, G8, G9> Pairwise(const G1& g1, const G2& g2, const G3& g3, const G4& g4, const G5& g5, const G6& g6, const G7& g7, const G8& g8, const G9& g9)
+{
+	return detail::iuPairwiseHolder9<G1, G2, G3, G4, G5, G6, G7, G8, G9>(g1, g2, g3, g4, g5, g6, g7, g8, g9);
+}
+
+#endif
+
+#endif
+
 }	// end of namespace iutest
 
 #endif	// IUTEST_HAS_PARAM_TEST
