@@ -19,8 +19,8 @@
 
 //======================================================================
 // include
-#include "iutest_defs.h"
-#include "internal/iutest_string.h"
+#include "iutest_defs.hpp"
+#include "internal/iutest_string.hpp"
 
 namespace iutest
 {
@@ -33,7 +33,7 @@ std::string PrintToString(const T& v);
 namespace detail
 {
 
-inline void PrintBytesInObjectTo(const unsigned char* buf, size_t size, ::std::ostream* os)
+inline void PrintBytesInObjectTo(const unsigned char* buf, size_t size, iu_ostream* os)
 {
 	const size_t kMaxCount = detail::kValues::MaxPrintContainerCount;
 	*os << size << "-Byte object < ";
@@ -59,7 +59,7 @@ class TypeWithoutFormatter
 	template<bool convertible, typename DMY>
 	struct impl
 	{
-		static void Print(const T& value, ::std::ostream* os)
+		static void Print(const T& value, iu_ostream* os)
 		{
 			const unsigned char* ptr = reinterpret_cast<const unsigned char*>(&value);
 			size_t size = sizeof(T);
@@ -69,25 +69,34 @@ class TypeWithoutFormatter
 	template<typename DMY>
 	struct impl<true, DMY>
 	{
-		static void Print(const T& value, ::std::ostream* os)
+		static void Print(const T& value, iu_ostream* os)
 		{
 			const BiggestInt v = value;
 			*os << v;
 		}
 	};
 public:
-	static void PrintValue(const T& value, ::std::ostream* os)
+	static void PrintValue(const T& value, iu_ostream* os)
 	{
 		impl<is_convertible<const T&, BiggestInt>::value, void>::Print(value, os);
 	}
 };
 
+#if IUTEST_HAS_STRINGSTREAM
 template<typename Elem, typename Traits, typename T>
 ::std::basic_ostream<Elem, Traits>& operator << (::std::basic_ostream<Elem, Traits>& os, const T& value)
 {
 	TypeWithoutFormatter<T>::PrintValue(value, &os);
 	return os;
 }
+#else
+template<typename T>
+iu_ostream& operator << (iu_ostream& os, const T& value)
+{
+	TypeWithoutFormatter<T>::PrintValue(value, &os);
+	return os;
+}
+#endif
 
 }	// end of printer_internal
 
@@ -99,7 +108,7 @@ namespace printer_internal2
 // ::operator <<
 // ::iutest::detail::printer_internal::operator <<
 template<typename T>
-void DefaultPrintNonContainerTo(const T& value, ::std::ostream* os)
+void DefaultPrintNonContainerTo(const T& value, iu_ostream* os)
 {
 	using namespace ::iutest::detail::printer_internal;
 	*os << value;
@@ -110,7 +119,7 @@ void DefaultPrintNonContainerTo(const T& value, ::std::ostream* os)
 //======================================================================
 // declare
 template<typename T>
-inline void UniversalPrintTo(T value, ::std::ostream* os);
+inline void UniversalPrintTo(T value, iu_ostream* os);
 
 //======================================================================
 // class
@@ -119,7 +128,7 @@ template<typename T>
 class iuUniversalPrinter
 {
 public:
-	static void Print(const T& value, ::std::ostream* os)
+	static void Print(const T& value, iu_ostream* os)
 	{
 		UniversalPrintTo(value, os);
 	}
@@ -129,7 +138,7 @@ public:
 // function
 /** @private */
 template<typename T>
-inline void	UniversalPrint(const T& value, ::std::ostream* os)
+inline void	UniversalPrint(const T& value, iu_ostream* os)
 {
 	iuUniversalPrinter<T>::Print(value, os);
 }
@@ -140,7 +149,7 @@ inline void	UniversalPrint(const T& value, ::std::ostream* os)
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::yes_t
 						   , false_type
-						   , const T& container, ::std::ostream* os)
+						   , const T& container, iu_ostream* os)
 {
 	const size_t kMaxCount = kValues::MaxPrintContainerCount;
 	size_t count = 0;
@@ -165,25 +174,25 @@ inline void DefaultPrintTo(IsContainerHelper::yes_t
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::no_t
 						   , false_type
-						   , const T& value, ::std::ostream* os)
+						   , const T& value, iu_ostream* os)
 {
 	printer_internal2::DefaultPrintNonContainerTo(value, os);
 }
 
 template<typename T>
-inline void DefaultPtrPrintTo(T* ptr, ::std::ostream* os, typename enable_if_t< is_convertible<T*, const void*> >::type*& = enabler::value)
+inline void DefaultPtrPrintTo(T* ptr, iu_ostream* os, typename enable_if_t< is_convertible<T*, const void*> >::type*& = enabler::value)
 {
 	*os << ptr;
 }
 template<typename T>
-inline void DefaultPtrPrintTo(T* ptr, ::std::ostream* os, typename disable_if_t< is_convertible<T*, const void*> >::type*& = enabler::value)
+inline void DefaultPtrPrintTo(T* ptr, iu_ostream* os, typename disable_if_t< is_convertible<T*, const void*> >::type*& = enabler::value)
 {
 	*os << reinterpret_cast<const void*>(reinterpret_cast<type_least_t<8>::UInt>(ptr));
 }
 template<typename T>
 inline void DefaultPrintTo(IsContainerHelper::no_t
 						   , true_type
-						   , T* ptr, ::std::ostream* os)
+						   , T* ptr, iu_ostream* os)
 {
 	if( ptr == NULL )
 	{
@@ -199,15 +208,15 @@ inline void DefaultPrintTo(IsContainerHelper::no_t
  * @brief	ϊ֐
 */
 template<typename T>
-inline void PrintTo(const T& value, ::std::ostream* os)	{ DefaultPrintTo(IsContainerHelper::IsContainer<T>(0), is_pointer<T>(), value, os); }
-inline void PrintTo(bool b, ::std::ostream* os)			{ *os << (b ? "true" : "false"); }
-inline void PrintTo(const char* c, ::std::ostream* os)	{ *os << c; }
-inline void PrintTo(char* c, ::std::ostream* os)		{ *os << c; }
-inline void PrintTo(const ::std::string& str, ::std::ostream* os)	{ *os << str.c_str(); }
+inline void PrintTo(const T& value, iu_ostream* os)	{ DefaultPrintTo(IsContainerHelper::IsContainer<T>(0), is_pointer<T>(), value, os); }
+inline void PrintTo(bool b, iu_ostream* os)			{ *os << (b ? "true" : "false"); }
+inline void PrintTo(const char* c, iu_ostream* os)	{ *os << c; }
+inline void PrintTo(char* c, iu_ostream* os)		{ *os << c; }
+inline void PrintTo(const ::std::string& str, iu_ostream* os)	{ *os << str.c_str(); }
 template<typename T>
-inline void PrintTo(const floating_point<T>& f, ::std::ostream* os)	{ *os << f.raw() << "(" << ToHexString(f.bit()) << ")"; }
+inline void PrintTo(const floating_point<T>& f, iu_ostream* os)	{ *os << f.raw() << "(" << ToHexString(f.bit()) << ")"; }
 template<typename T1, typename T2>
-inline void PrintTo(const ::std::pair<T1, T2>& value, ::std::ostream* os)
+inline void PrintTo(const ::std::pair<T1, T2>& value, iu_ostream* os)
 {
 	*os << "(";
 	iuUniversalPrinter<T1>::Print(value.first, os);
@@ -216,83 +225,83 @@ inline void PrintTo(const ::std::pair<T1, T2>& value, ::std::ostream* os)
 	*os << ")";
 }
 // char or unsigned char ̎ɁA 0  NULL ɂȂȂ悤ɏC
-inline void PrintTo(const char value, ::std::ostream* os)
+inline void PrintTo(const char value, iu_ostream* os)
 {
 	if( value == 0 ) *os << "\\0";
 	else *os << "\'" << value << "\'";
 }
-inline void PrintTo(const wchar_t value, ::std::ostream* os)
+inline void PrintTo(const wchar_t value, iu_ostream* os)
 {
 	if( value == 0 ) *os << "\\0";
 	else *os << "\'" << value << "\'";
 }
-inline void PrintTo(const unsigned char value, ::std::ostream* os)
+inline void PrintTo(const unsigned char value, iu_ostream* os)
 {
 	*os << static_cast<unsigned int>(value);
 }
 
 #if IUTEST_HAS_NULLPTR
-inline void PrintTo(const ::std::nullptr_t&, ::std::ostream* os) { *os << "nullptr"; }
+inline void PrintTo(const ::std::nullptr_t&, iu_ostream* os) { *os << "nullptr"; }
 #endif
 
 #if IUTEST_HAS_TUPLE
 
 template<typename T, int I, int SIZE>
-inline void PrintTupleElemTo(const T& t, ::std::ostream* os, typename detail::enable_if<I == 0, void>::type*& = detail::enabler::value)
+inline void PrintTupleElemTo(const T& t, iu_ostream* os, typename detail::enable_if<I == 0, void>::type*& = detail::enabler::value)
 {
 	IUTEST_UNUSED_VAR(t);
 	IUTEST_UNUSED_VAR(os);
 }
 template<typename T, int I, int SIZE>
-inline void PrintTupleElemTo(const T& t, ::std::ostream* os, typename detail::enable_if<I == 1, void>::type*& = detail::enabler::value)
+inline void PrintTupleElemTo(const T& t, iu_ostream* os, typename detail::enable_if<I == 1, void>::type*& = detail::enabler::value)
 {
-	PrintTo(tuple::get<SIZE-I>(t), os);
+	PrintTo(tuples::get<SIZE-I>(t), os);
 }
 template<typename T, int I, int SIZE>
-inline void PrintTupleElemTo(const T& t, ::std::ostream* os, typename detail::enable_if<(I&(~1)) != 0, void>::type*& = detail::enabler::value)
+inline void PrintTupleElemTo(const T& t, iu_ostream* os, typename detail::enable_if<(I&(~1)) != 0, void>::type*& = detail::enabler::value)
 {
-	PrintTo(tuple::get<SIZE-I>(t), os);
+	PrintTo(tuples::get<SIZE-I>(t), os);
 	*os << ", ";
 	PrintTupleElemTo<T, I-1, SIZE>(t, os);
 }
 
 template<typename T>
-inline void PrintTupleTo(const T& t, ::std::ostream* os)
+inline void PrintTupleTo(const T& t, iu_ostream* os)
 {
 	*os << "(";
-	PrintTupleElemTo<T, tuple::tuple_size<T>::value, tuple::tuple_size<T>::value>(t, os);
+	PrintTupleElemTo<T, tuples::tuple_size<T>::value, tuples::tuple_size<T>::value>(t, os);
 	*os << ")";
 }
 
-#if IUTEST_HAS_VARIADIC_TEMPLATES
+#if IUTEST_HAS_VARIADIC_TEMPLATES && IUTEST_HAS_TUPLE
 
 template<typename ...Args>
-inline void PrintTo(const tuple::tuple<Args...>& t, ::std::ostream* os)
+inline void PrintTo(const tuples::tuple<Args...>& t, iu_ostream* os)
 {
 	PrintTupleTo(t, os);
 }
 
 #else
 
-inline void PrintTo(const tuple::tuple<>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1>
-inline void PrintTo(const tuple::tuple<A1>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2>
-inline void PrintTo(const tuple::tuple<A1, A2>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3>
-inline void PrintTo(const tuple::tuple<A1, A2, A3>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4, typename A5>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4, typename A5, typename A6>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5, A6>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5, A6>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4, typename A5, typename A6, typename A7>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5, A6, A7>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5, A6, A7>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4, typename A5, typename A6, typename A7, typename A8>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5, A6, A7, A8>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5, A6, A7, A8>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 template<typename A1, typename A2, typename A3, typename A4, typename A5, typename A6, typename A7, typename A8, typename A9>
-inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5, A6, A7, A8, A9>& t, ::std::ostream* os) { PrintTupleTo(t, os); }
+inline void PrintTo(const tuples::tuple<A1, A2, A3, A4, A5, A6, A7, A8, A9>& t, iu_ostream* os) { PrintTupleTo(t, os); }
 
 #endif
 
@@ -303,17 +312,17 @@ inline void PrintTo(const tuple::tuple<A1, A2, A3, A4, A5, A6, A7, A8, A9>& t, :
 
 /** @private */
 template<typename T>
-inline void	IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const T& value, ::std::ostream* os)
+inline void	IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const T& value, iu_ostream* os)
 {
 	UniversalPrint(value, os);
 }
 
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const char* str, ::std::ostream* os)
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(const char* str, iu_ostream* os)
 {
 	if( str == NULL ) *os << kStrings::Null;
 	else UniversalPrint(::std::string(str), os);
 }
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char* str, ::std::ostream* os)
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char* str, iu_ostream* os)
 {
 	UniversalTersePrint(static_cast<const char*>(str), os);
 }
@@ -322,7 +331,7 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalTersePrint(char* str, ::std::ostre
  * @brief	z̏o
 */
 template<typename T>
-inline void PrintRawArrayTo(const T* a, size_t cnt, ::std::ostream* os)
+inline void PrintRawArrayTo(const T* a, size_t cnt, iu_ostream* os)
 {
 	UniversalPrint<T>(a[0], os);
 	for( size_t i=1; i < cnt; ++i )
@@ -336,7 +345,7 @@ inline void PrintRawArrayTo(const T* a, size_t cnt, ::std::ostream* os)
  * @brief	z̏o
 */
 template<typename T>
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const T* begin, size_t N, ::std::ostream* os)
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const T* begin, size_t N, iu_ostream* os)
 {
 	if( N == 0 ) *os << "{}";
 	else
@@ -360,7 +369,7 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const T* begin, size_t
 /**
  * @brief	z̏o
 */
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const char* begin, size_t N, ::std::ostream* os)
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const char* begin, size_t N, iu_ostream* os)
 {
 	IUTEST_UNUSED_VAR(N);
 	UniversalTersePrint(begin, os);
@@ -371,14 +380,14 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintArray(const char* begin, size
 
 /** @private */
 template<typename T>
-inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintTo(T value, ::std::ostream* os) { PrintTo(value, os); }
+inline void IUTEST_ATTRIBUTE_UNUSED_ UniversalPrintTo(T value, iu_ostream* os) { PrintTo(value, os); }
 
 /** @private */
 template<typename T, size_t SIZE>
 class iuUniversalPrinter<T[SIZE]>
 {
 public:
-	static void Print(const T (&a)[SIZE], ::std::ostream* os)
+	static void Print(const T (&a)[SIZE], iu_ostream* os)
 	{
 		UniversalPrintArray(a, SIZE, os);
 	}
