@@ -34,6 +34,10 @@ int wmain(int argc, wchar_t* argv[])
 int main(int argc, char* argv[])
 #endif
 {
+#if !defined(IUTEST_OS_WINDOWS_MOBILE)
+	setlocale(LC_CTYPE, "");
+#endif
+
 #if 1
 	iutest::AddGlobalTestEnvironment(new FooEnvironment());
 #endif
@@ -447,15 +451,15 @@ IUTEST_P(TestPValuesN, TestA)
 
 #if IUTEST_HAS_COMBINE
 
-class TestPCombine : public ::iutest::TestWithParam< ::iutest::tuple::tuple<bool, int, int> >
+class TestPCombine : public ::iutest::TestWithParam< ::iutest::tuples::tuple<bool, int, int> >
 {
 };
 
 IUTEST_P(TestPCombine, TestA)
 {
-	bool b = ::iutest::tuple::get<0>(GetParam());
-	int i1 = ::iutest::tuple::get<1>(GetParam());
-	int i2 = ::iutest::tuple::get<2>(GetParam());
+	bool b = ::iutest::tuples::get<0>(GetParam());
+	int i1 = ::iutest::tuples::get<1>(GetParam());
+	int i2 = ::iutest::tuples::get<2>(GetParam());
 	IUTEST_SUCCEED() << b << ", " << i1 << ", " << i2;
 }
 
@@ -557,6 +561,10 @@ static void	ExceptionFunction(int i)
 	case 2:
 		throw ::std::bad_exception();
 		break;
+	case 3:
+		throw "error";
+	case 4:
+		throw ::std::string("error");
 	default:
 		break;
 	}
@@ -567,6 +575,12 @@ IUTEST(AssertionTest, Exception)
 	IUTEST_EXPECT_THROW(ExceptionFunction(2), ::std::bad_exception);
 	IUTEST_EXPECT_ANY_THROW(ExceptionFunction(1));
 	IUTEST_EXPECT_NO_THROW(ExceptionFunction(0));
+
+	IUTEST_EXPECT_THROW_VALUE_EQ(ExceptionFunction(1), int, 2);
+	IUTEST_EXPECT_THROW_VALUE_NE(ExceptionFunction(1), int, 0);
+
+	IUTEST_ASSERT_THROW_VALUE_STREQ(ExceptionFunction(3), const char *, "error");
+	IUTEST_ASSERT_THROW_VALUE_STRCASEEQ(ExceptionFunction(3), const char *, "Error");
 }
 
 class exception_test
@@ -720,6 +734,12 @@ IUTEST(TestExpectFailure, Exception)
 	IUTEST_EXPECT_THROW(ExceptionFunction(0), int);
 	IUTEST_EXPECT_ANY_THROW(ExceptionFunction(0));
 	IUTEST_EXPECT_NO_THROW(ExceptionFunction(2));
+
+	IUTEST_EXPECT_THROW_VALUE_EQ(ExceptionFunction(1), int, 0);
+	IUTEST_EXPECT_THROW_VALUE_NE(ExceptionFunction(1), int, 2);
+
+	IUTEST_EXPECT_THROW_VALUE_STREQ(ExceptionFunction(3), const char *, "Error");
+	IUTEST_EXPECT_THROW_VALUE_STRCASEEQ(ExceptionFunction(3), const char *, "rror");
 }
 IUTEST(TestExpectFailure, UnexpectedException1)
 {
